@@ -8,11 +8,13 @@ import (
 	"regexp"
 	"runtime"
 	"strings"
+	"time"
 
 	log "github.com/sirupsen/logrus"
 
 	"github.com/nektos/act/pkg/common"
 	"github.com/nektos/act/pkg/container"
+	"github.com/nektos/act/pkg/exprparser"
 	"github.com/nektos/act/pkg/model"
 )
 
@@ -23,34 +25,35 @@ type Runner interface {
 
 // Config contains the config for a new runner
 type Config struct {
-	Actor                 string                       // the user that triggered the event
-	Workdir               string                       // path to working directory
-	BindWorkdir           bool                         // bind the workdir to the job container
-	EventName             string                       // name of event to run
-	EventPath             string                       // path to JSON file to use for event.json in containers
-	DefaultBranch         string                       // name of the main branch for this repository
-	ReuseContainers       bool                         // reuse containers to maintain state
-	ForcePull             bool                         // force pulling of the image, even if already present
-	ForceRebuild          bool                         // force rebuilding local docker image action
-	LogOutput             bool                         // log the output from docker run
-	JSONLogger            bool                         // use json or text logger
-	Env                   map[string]string            // env for containers
-	Secrets               map[string]string            // list of secrets
-	InsecureSecrets       bool                         // switch hiding output when printing to terminal
-	Platforms             map[string]string            // list of platforms
-	Privileged            bool                         // use privileged mode
-	UsernsMode            string                       // user namespace to use
-	ContainerArchitecture string                       // Desired OS/architecture platform for running containers
-	ContainerDaemonSocket string                       // Path to Docker daemon socket
-	UseGitIgnore          bool                         // controls if paths in .gitignore should not be copied into container, default true
-	GitHubInstance        string                       // GitHub instance to use, default "github.com"
-	ContainerCapAdd       []string                     // list of kernel capabilities to add to the containers
-	ContainerCapDrop      []string                     // list of kernel capabilities to remove from the containers
-	AutoRemove            bool                         // controls if the container is automatically removed upon workflow completion
-	ArtifactServerPath    string                       // the path where the artifact server stores uploads
-	ArtifactServerPort    string                       // the port the artifact server binds to
-	CompositeRestrictions *model.CompositeRestrictions // describes which features are available in composite actions
-	NoSkipCheckout        bool                         // do not skip actions/checkout
+	Actor                 string            // the user that triggered the event
+	Workdir               string            // path to working directory
+	BindWorkdir           bool              // bind the workdir to the job container
+	EventName             string            // name of event to run
+	EventPath             string            // path to JSON file to use for event.json in containers
+	DefaultBranch         string            // name of the main branch for this repository
+	ReuseContainers       bool              // reuse containers to maintain state
+	ForcePull             bool              // force pulling of the image, even if already present
+	ForceRebuild          bool              // force rebuilding local docker image action
+	LogOutput             bool              // log the output from docker run
+	JSONLogger            bool              // use json or text logger
+	Env                   map[string]string // env for containers
+	Secrets               map[string]string // list of secrets
+	Token                 string            // GitHub token
+	InsecureSecrets       bool              // switch hiding output when printing to terminal
+	Platforms             map[string]string // list of platforms
+	Privileged            bool              // use privileged mode
+	UsernsMode            string            // user namespace to use
+	ContainerArchitecture string            // Desired OS/architecture platform for running containers
+	ContainerDaemonSocket string            // Path to Docker daemon socket
+	UseGitIgnore          bool              // controls if paths in .gitignore should not be copied into container, default true
+	GitHubInstance        string            // GitHub instance to use, default "github.com"
+	ContainerCapAdd       []string          // list of kernel capabilities to add to the containers
+	ContainerCapDrop      []string          // list of kernel capabilities to remove from the containers
+	AutoRemove            bool              // controls if the container is automatically removed upon workflow completion
+	ArtifactServerPath    string            // the path where the artifact server stores uploads
+	ArtifactServerPort    string            // the port the artifact server binds to
+	NoSkipCheckout        bool              // do not skip actions/checkout
+	RemoteName            string            // remote name in local git repo config
 }
 
 // Resolves the equivalent host path inside the container
@@ -116,6 +119,8 @@ func New(runnerConfig *Config) (Runner, error) {
 	return runner, nil
 }
 
+// NewPlanExecutor ...
+//nolint:gocyclo
 func (runner *runnerImpl) NewPlanExecutor(plan *model.Plan) common.Executor {
 	maxJobNameLen := 0
 
@@ -128,9 +133,14 @@ func (runner *runnerImpl) NewPlanExecutor(plan *model.Plan) common.Executor {
 			for r, run := range stage.Runs {
 				stageExecutor := make([]common.Executor, 0)
 				job := run.Job()
+
+				if job.Uses != "" {
+					return fmt.Errorf("reusable workflows are currently not supported (see https://github.com/nektos/act/issues/826 for updates)")
+				}
+
 				if job.Strategy != nil {
-					strategyRc := runner.newRunContext(run, nil)
-					if err := strategyRc.NewExpressionEvaluator().EvaluateYamlNode(&job.Strategy.RawMatrix); err != nil {
+					strategyRc := runner.newRunContext(ctx, run, nil)
+					if err := strategyRc.NewExpressionEvaluator(ctx).EvaluateYamlNode(ctx, &job.Strategy.RawMatrix); err != nil {
 						log.Errorf("Error while evaluating matrix: %v", err)
 					}
 				}
@@ -145,15 +155,24 @@ func (runner *runnerImpl) NewPlanExecutor(plan *model.Plan) common.Executor {
 				}
 
 				for i, matrix := range matrixes {
-					rc := runner.newRunContext(run, matrix)
+					rc := runner.newRunContext(ctx, run, matrix)
 					rc.JobName = rc.Name
 					if len(matrixes) > 1 {
 						rc.Name = fmt.Sprintf("%s-%d", rc.Name, i+1)
 					}
+					// evaluate environment variables since they can contain
+					// GitHub's special environment variables.
+					for k, v := range rc.GetEnv() {
+						valueEval, err := rc.ExprEval.evaluate(ctx, v, exprparser.DefaultStatusCheckNone)
+						if err == nil {
+							rc.Env[k] = fmt.Sprintf("%v", valueEval)
+						}
+					}
 					if len(rc.String()) > maxJobNameLen {
 						maxJobNameLen = len(rc.String())
 					}
 					stageExecutor = append(stageExecutor, func(ctx context.Context) error {
+						logger := common.Logger(ctx)
 						jobName := fmt.Sprintf("%-*s", maxJobNameLen, rc.String())
 						return rc.Executor().Finally(func(ctx context.Context) error {
 							isLastRunningContainer := func(currentStage int, currentRun int) bool {
@@ -161,14 +180,21 @@ func (runner *runnerImpl) NewPlanExecutor(plan *model.Plan) common.Executor {
 							}
 
 							if runner.config.AutoRemove && isLastRunningContainer(s, r) {
+								var cancel context.CancelFunc
+								if ctx.Err() == context.Canceled {
+									ctx, cancel = context.WithTimeout(context.Background(), 5*time.Minute)
+									defer cancel()
+								}
+
 								log.Infof("Cleaning up container for job %s", rc.JobName)
+
 								if err := rc.stopJobContainer()(ctx); err != nil {
-									log.Errorf("Error while cleaning container: %v", err)
+									logger.Errorf("Error while cleaning container: %v", err)
 								}
 							}
 
 							return nil
-						})(common.WithJobErrorContainer(WithJobLogger(ctx, jobName, rc.Config, &rc.Masks)))
+						})(common.WithJobErrorContainer(WithJobLogger(ctx, rc.Run.JobID, jobName, rc.Config, &rc.Masks)))
 					})
 				}
 				pipeline = append(pipeline, common.NewParallelExecutor(maxParallel, stageExecutor...))
@@ -201,7 +227,7 @@ func handleFailure(plan *model.Plan) common.Executor {
 	}
 }
 
-func (runner *runnerImpl) newRunContext(run *model.Run, matrix map[string]interface{}) *RunContext {
+func (runner *runnerImpl) newRunContext(ctx context.Context, run *model.Run, matrix map[string]interface{}) *RunContext {
 	rc := &RunContext{
 		Config:      runner.config,
 		Run:         run,
@@ -209,7 +235,7 @@ func (runner *runnerImpl) newRunContext(run *model.Run, matrix map[string]interf
 		StepResults: make(map[string]*model.StepResult),
 		Matrix:      matrix,
 	}
-	rc.ExprEval = rc.NewExpressionEvaluator()
-	rc.Name = rc.ExprEval.Interpolate(run.String())
+	rc.ExprEval = rc.NewExpressionEvaluator(ctx)
+	rc.Name = rc.ExprEval.Interpolate(ctx, run.String())
 	return rc
 }
